==> haskell-websockets-0.12.7.3-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 websockets
version:              0.12.7.3
visibility:           public
id:                   websockets-0.12.7.3-CFeRzZc610cFMW3Tm6kg94
key:                  websockets-0.12.7.3-CFeRzZc610cFMW3Tm6kg94
license:              BSD-3-Clause
copyright:
    (c) 2010-2011 Siniša Biđin
    (c) 2011-2018 Jasper Van der Jeugt
    (c) 2011 Steffen Schuldenzucker
    (c) 2011 Alex Lang

maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:
    Siniša Biđin <sinisa@bidin.cc>
    Jasper Van der Jeugt <m@jaspervdj.be>
    Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
    Alex Lang <lang@tsurucapital.com>

stability:            experimental
homepage:             http://jaspervdj.be/websockets
synopsis:
    A sensible and clean way to write WebSocket-capable servers in Haskell.

description:
    This library allows you to write WebSocket-capable servers.

    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>

    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>

    See also:

    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>

    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>

category:             Network
abi:                  b889a9c9cd792a8718fab647662f833a
exposed:              True
exposed-modules:
    Network.WebSockets Network.WebSockets.Client
    Network.WebSockets.Connection Network.WebSockets.Extensions
    Network.WebSockets.Stream

hidden-modules:
    Network.WebSockets.Connection.Options
    Network.WebSockets.Extensions.Description
    Network.WebSockets.Extensions.PermessageDeflate
    Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
    Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
    Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
    Network.WebSockets.Server Network.WebSockets.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/websockets-0.12.7.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/websockets-0.12.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-websockets
hs-libraries:         HSwebsockets-0.12.7.3-CFeRzZc610cFMW3Tm6kg94
depends:
    SHA-1.6.4.4-1UNVNO3JXJdDGqRoMkntZx
    async-2.2.4-BQljimKC9bM4zvFoLpwvUr
    attoparsec-0.14.4-3hmNOn9KsQkLastvrl1LA3 base-4.15.1.0
    base64-bytestring-1.2.1.0-H46CYAE3oqvFn1pyH5O1iU binary-0.8.8.0
    bytestring-0.10.12.1
    case-insensitive-1.2.1.0-5VDT8fH2EuK8lxYh6ZMoM9
    clock-0.8.3-yALU8MiIiZAn3bMHCled3 containers-0.6.4.1
    entropy-0.4.1.7-Af27lR5RV911FT1IImZ36i
    network-3.1.2.7-4fHPmLRayzE3jBFWfdd8H
    random-1.2.1-1Hz8B867VBj7K7atSeCZU3
    streaming-commons-0.2.2.4-1gs9DzYMewTKEkDaBmH5K4 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html:         /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-websockets-0.12.7.3-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 websockets
version:              0.12.7.3
visibility:           public
id:                   websockets-0.12.7.3-4ivgbLWuSQRKiGME1pePfi
key:                  websockets-0.12.7.3-4ivgbLWuSQRKiGME1pePfi
license:              BSD-3-Clause
copyright:
    (c) 2010-2011 Siniša Biđin
    (c) 2011-2018 Jasper Van der Jeugt
    (c) 2011 Steffen Schuldenzucker
    (c) 2011 Alex Lang

maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:
    Siniša Biđin <sinisa@bidin.cc>
    Jasper Van der Jeugt <m@jaspervdj.be>
    Steffen Schuldenzucker <steffen.schuldenzucker@googlemail.com>
    Alex Lang <lang@tsurucapital.com>

stability:            experimental
homepage:             http://jaspervdj.be/websockets
synopsis:
    A sensible and clean way to write WebSocket-capable servers in Haskell.

description:
    This library allows you to write WebSocket-capable servers.

    An example server:
    <https://github.com/jaspervdj/websockets/blob/master/example/server.lhs>

    An example client:
    <https://github.com/jaspervdj/websockets/blob/master/example/client.hs>

    See also:

    * The specification of the WebSocket protocol:
    <http://www.whatwg.org/specs/web-socket-protocol/>

    * The JavaScript API for dealing with WebSockets:
    <http://www.w3.org/TR/websockets/>

category:             Network
abi:                  8265d743de80da421ac46b1862b519a2
exposed:              True
exposed-modules:
    Network.WebSockets Network.WebSockets.Client
    Network.WebSockets.Connection Network.WebSockets.Extensions
    Network.WebSockets.Stream

hidden-modules:
    Network.WebSockets.Connection.Options
    Network.WebSockets.Extensions.Description
    Network.WebSockets.Extensions.PermessageDeflate
    Network.WebSockets.Extensions.StrictUnicode Network.WebSockets.Http
    Network.WebSockets.Hybi13 Network.WebSockets.Hybi13.Demultiplex
    Network.WebSockets.Hybi13.Mask Network.WebSockets.Protocol
    Network.WebSockets.Server Network.WebSockets.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/websockets-0.12.7.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/websockets-0.12.7.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-websockets
hs-libraries:         HSwebsockets-0.12.7.3-4ivgbLWuSQRKiGME1pePfi
depends:
    SHA-1.6.4.4-1UNVNO3JXJdDGqRoMkntZx
    async-2.2.4-DsK1F0iuVhj9HaenwCyvAG
    attoparsec-0.14.4-3b5hJmAVxMZ2YoY0FeNqg3 base-4.15.1.0
    base64-bytestring-1.2.1.0-D33qXGXKpGmJ3T6mGyl7f0 binary-0.8.8.0
    bytestring-0.10.12.1
    case-insensitive-1.2.1.0-AmrqIhTD8km9mbo5tnh83Q
    clock-0.8.3-7ZYpQKZGj5bJL4HzR4QZG5 containers-0.6.4.1
    entropy-0.4.1.7-Af27lR5RV911FT1IImZ36i
    network-3.1.2.7-EuFNMFR0kXs1j7tEW9CoN1
    random-1.2.1-E3c41PA01kCLyHrUUW2INz
    streaming-commons-0.2.2.4-17afb4w9Gtq9opXZ43eNPB text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-websockets/html/websockets.haddock
haddock-html:         /usr/share/doc/haskell-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
